"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.patchRequest = exports.putRequest = exports.postRequest = exports.getRequest = exports.request = void 0;

var _makeRequest = require("./makeRequest.js");

var _baseUrl = require("../services/baseUrl.js");

var _headers = require("../services/headers.js");

var _validateRequiredParams = require("./validateRequiredParams.js");

var _validateBaseUrl = require("./validateBaseUrl.js");

var _validatePayload = require("./validatePayload.js");

var _constants = require("../constants/constants.js");

const request = (urlMaker, method = _constants.GET, requestInterface = {}, fetchMaker = _makeRequest.makeRequest) => (...args) => {
  try {
    const [urlParams = {}, payload = {}] = args.filter(arg => typeof arg === 'object');
    const customBaseUrl = args.find(arg => typeof arg === 'string') || (0, _baseUrl.get)();
    const resource = (0, _validateBaseUrl.validateBaseUrl)(customBaseUrl);
    const url = typeof urlMaker === 'function' ? urlMaker(urlParams) : urlMaker || '';
    const validUrl = (0, _validateRequiredParams.validateRequiredParams)(`${resource}${url}`);
    let requestParams = {
      method,
      headers: (0, _headers.get)()
    };

    if (Object.keys(payload).length > 0) {
      requestParams = { ...requestParams,
        body: (0, _validatePayload.validatePayload)(requestInterface, payload, method)
      };
    }

    return fetchMaker(validUrl, requestParams);
  } catch (err) {
    return Promise.reject(err);
  }
};

exports.request = request;

const getRequest = (urlMaker, fetchMaker) => request(urlMaker, _constants.GET, fetchMaker);

exports.getRequest = getRequest;

const postRequest = (urlMaker, requestInterface, fetchMaker) => request(urlMaker, _constants.POST, requestInterface, fetchMaker);

exports.postRequest = postRequest;

const putRequest = (urlMaker, requestInterface, fetchMaker) => request(urlMaker, _constants.PUT, requestInterface, fetchMaker);

exports.putRequest = putRequest;

const patchRequest = (urlMaker, requestInterface, fetchMaker) => request(urlMaker, _constants.PATCH, requestInterface, fetchMaker);

exports.patchRequest = patchRequest;