import * as merchantModels from './merchantModels';

describe('merchantModels', () => {
  it('Should return correct Merchant Contacts model.', () => {
    const modeledResponse = [{
      name: 'xpto',
      email: 'xpto@stone.com.br',
      phone: '22222222',
      mobilePhone: '12345678',
      typeName: '12345',
    }];

    const contactsData = [
      {
        name: 'xpto',
        email: 'xpto@stone.com.br',
        phone: '22222222',
        mobilePhone: '12345678',
        typeName: '12345',
      }];

    expect(merchantModels.contactsModel(contactsData))
      .to.deep.equal(modeledResponse);
  });

  it('Should return correct Put Merchant Contacts model.', () => {
    const modeledResponse = {
      name: 'xpto',
      email: 'xpto@stone.com.br',
      phone: '2199999999',
      mobilePhone: '21999999999',
      typeId: 1,
    };

    const contactsData = {
      name: 'xpto',
      email: 'xpto@stone.com.br',
      phone: '(21) 9999-9999',
      mobilePhone: '(21) 99999-9999',
      typeId: '1',
    };

    expect(merchantModels.putContactsModel(contactsData))
      .to.deep.equal(modeledResponse);
  });


  it('Should return correct Merchant Partners model.', () => {
    const partnerData = [{
      name: 'xpto',
      test: '12345',
      email: 'xpto@stone.com.br',
      rg: '111111111',
      cpf: '111.111.111.111',
      param_2: 'mock',
    }];
    expect(merchantModels.partnersModel(partnerData))
      .to.eql([{
        name: 'xpto',
        email: 'xpto@stone.com.br',
        rg: '111111111',
        cpf: '111.111.111.111',
      }]);
  });

  it('Should return correct Merchant Addresses model.', () => {
    const addressesData = [
      {
        typeName: 'Xpto principal',
        stateName: 'RS',
        cityName: 'Porto Alegre',
        streetName: 'Rua 1',
        streetNumber: '35',
        complement: '10',
        neighborhood: 'XPTO',
      }];

    expect(merchantModels.addressesModel(addressesData))
      .to.eql([{
        description: 'Xpto principal',
        uf: 'RS',
        city: 'Porto Alegre',
        street: 'Rua 1',
        number: '35',
        complement: '10',
        neighborhood: 'XPTO',
      }]);
  });

  it('Should return correct Merchant Info model.', () => {
    const stoneCodeMock = '123456789';
    const infoData = {
      prop: 'xpto',
      stonecode: '1234567',
      document: '111.111-11111',
      companyName: 'Mock_xpto',
      fantasyName: 'Mock fantasy',
      mccDescription: 'mock mcc',
    };

    expect(merchantModels.infoModel(infoData, stoneCodeMock))
      .to.eql([{
        stonecode: '123456789',
        cnpj: '111.111-11111',
        companyName: 'Mock_xpto',
        fantasyName: 'Mock fantasy',
        mccDescription: 'mock mcc',
      }]);
  });

  it('Should return correct Merchant Bank Info model.', () => {
    const infoData = [
      {
        data: [{
          id: 111,
          compeCode: 111,
          ispbCode: 11111,
          name: 'test',
          accountTypes: [
            {
              id: 2,
              name: 'test',
            },
            {
              id: 1,
              name: 'test',
            },
          ],
        }],
      },
      {
        data: [{
          affiliationCode: 111,
          id: 111,
          accountNumber: 2222,
          accountNumberVerificationCode: 2,
          agencyNumber: 1111,
          agencyNumberVerificationCode: 2,
          bankId: 4,
          bankName: 'test',
          statusId: 4,
          typeId: 1,
          typeName: 'test',
          centralizedPayment: false,
        }],
      },
    ];
    expect(merchantModels.bankInfoModel(infoData))
      .to.eql({
        banks: [{
          affiliationCode: 111,
          id: 111,
          accountNumber: 2222,
          accountNumberVerificationCode: 2,
          agencyNumber: 1111,
          agencyNumberVerificationCode: 2,
          bankId: 4,
          bankName: 'test',
          statusId: 4,
          typeId: 1,
          typeName: 'test',
          centralizedPayment: false,
        }],
        availableBanks: [{
          id: 111,
          compeCode: 111,
          ispbCode: 11111,
          name: 'test',
          accountTypes: [
            {
              id: 2,
              name: 'test',
            },
            {
              id: 1,
              name: 'test',
            },
          ],
        }],
      });
  });

  describe('#feesModel([trxProfiles, cardBrands, merchantFees])', () => {
    const trxProfiles = {
      data: [
        {
          id: 1,
          name: 'Crédito à Vista',
        },
        {
          id: 2,
          name: 'Crédito de 2 a 6 parcelas s/ juros',
        },
      ],
    };
    const cardBrands = {
      data: [
        {
          id: 1,
          name: 'Visa',
        },
        {
          id: 2,
          name: 'MasterCard',
        },
      ],
    };
    const merchantFees = {
      data: [
        {
          cardBrandId: 1,
          transactionProfileId: 1,
          rate: 1.99,
        },
        {
          cardBrandId: 1,
          transactionProfileId: 2,
          rate: 2.28,
        },
        {
          cardBrandId: 2,
          transactionProfileId: 1,
          rate: 1.99,
        },
      ],
    };

    it('Should return correct Merchant Fees model.', () => {
      expect(merchantModels.feesModel([trxProfiles, cardBrands, merchantFees]))
        .to.deep.equal([
          {
            cardBrandId: 1,
            cardBrandName: 'Visa',
            transactionProfileId: 1,
            transactionProfileName: 'Crédito à Vista',
            rate: 1.99,
          },
          {
            cardBrandId: 1,
            cardBrandName: 'Visa',
            transactionProfileId: 2,
            transactionProfileName: 'Crédito de 2 a 6 parcelas s/ juros',
            rate: 2.28,
          },
          {
            cardBrandId: 2,
            cardBrandName: 'MasterCard',
            transactionProfileId: 1,
            transactionProfileName: 'Crédito à Vista',
            rate: 1.99,
          },
        ]);
    });
  });
});
