import sinon from 'sinon';
import { service as authenticateService } from './authenticate.js';
import { authenticateInterface } from './authenticateInterface.js';

const urlParams = {};

describe('Credentials Authenticate Module', () => {
  it('Should have methods after initialization.', () => {
    const service = authenticateService();
    expect(service.post).to.be.a('function');
  });

  it('Should call post request.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = authenticateService(postRequest);

    service.post(urlParams, authenticateInterface);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call post request and return a valid URL.', () => {
    const spy = sinon.spy();

    const postRequest = (urlString) => {
      spy(urlString);
      return () => {};
    };

    const service = authenticateService(postRequest);

    service.post(urlParams, authenticateInterface);

    expect(spy).to.have.been.calledOnceWith('v0/authenticate');
  });

  it('Should call post request with valid params.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = authenticateService(postRequest);

    service.post(urlParams);

    expect(spy).to.have.been.calledOnceWith(urlParams);
  });
});
