import sinon from 'sinon';

import { service as operationsService } from './operations.js';

const urlParams = {
  affiliationCodes: '321321321',
  startDate: '2018-06-01',
  finalDate: '2018-06-01',
  walletTypeId: 6,
  page: 0,
  pageSize: 10,
};

describe('Operations Module', () => {
  it('Should have methods after initialization.', () => {
    const service = operationsService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = operationsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = operationsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/payments/operations?affiliationCodes=321321321' +
        '&startDate=2018-06-01&finalDate=2018-06-01&page=0&pageSize=10');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = operationsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
