import sinon from 'sinon';

import { service as paymentsService } from './payments.js';

const urlParams = {
  affiliationCodes: '321321321',
  startDate: '2018-06-01',
  finalDate: '2018-06-01',
  crossBalance: 'true',
  walletTypeId: '6',
};

const urlRequiredParams = {
  affiliationCodes: '321321321',
  startDate: '2018-06-01',
  finalDate: '2018-06-01',
};

describe('Payments Module', () => {
  it('Should have methods after initialization.', () => {
    const service = paymentsService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = paymentsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = paymentsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/payments?affiliationCodes=321321321' +
        '&startDate=2018-06-01&finalDate=2018-06-01&crossBalance=true' +
        '&walletTypeId=6');
  });

  it('Should call get request and return a valid URL ' +
    'when passed only required parameters.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlRequiredParams));
      return () => {};
    };

    const service = paymentsService(getRequest);

    service.get(urlRequiredParams);

    expect(spy).to.have.been
      .calledWith('v0/payments?affiliationCodes=321321321' +
        '&startDate=2018-06-01&finalDate=2018-06-01&crossBalance=false');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = paymentsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
